# -*- coding: utf-8 -*-
# @package Index Sentinel Files
"""
Example:

        $ python -m doctest -v Index.py
"""

""" Class for Sentinel satellites configuration
Test Case
>>> Files = tools('MSIL1C')
>>> dir="C:\Users\Garantias723\Documents\Poncho\Image_Sentinel"
>>> platform='Sentinel-2'
>>> list_files=Files.findFilesSentinel(dir,platform)
>>> print 'There is/are %d ' % len(list_files) + platform + ' file(s)'
>>> read=readProduct(dir,platform)
>>> for image in list_files:
>>> file = dir + "/" + image
>>> read.ReadfilesSentinel(file)
>>> band_names = product.getBandNames()
>>> print("Bands:   %s" % (list(band_names)))

 """

import os,sys
sys.path.append(os.path.join(os.path.expandvars("%userprofile%"),".snap\snap-python"))
import snappy,numpy
from snappy import HashMap,jpy,Product,ProductData,ProductIO,ProductUtils
from tools import (tools)
from readProduct import (readProduct)

class Index(object):


    def __init__(self,ResolSize,IndexType):
        """The constructor Initialize Sentinel Data.

        Args:
            self: The object pointer.
            folder (str): destination directory.

        Returns:
            pointer: The object pointer.
        """
        self.resolution=ResolSize
        self.Index_Type=IndexType
        self.typeNDVI = "NDVI"
        self.typeNDWI = "NDWI"
        self.typeNBAI = "NBAI"
        self.HashMap = jpy.get_type('java.util.HashMap')

    def Index(self,product, file):

        width = product.getSceneRasterWidth()
        height = product.getSceneRasterHeight()
        product_name = product.getName()

        # input product red & nir bands
        #if (self.Index_Type == "NDVI"):
        if (self.Index_Type == self.typeNDVI):
            print"Entre NDVI..."
            type=self.typeNDVI
            red_band = product.getBand('B4')
            nir_band = product.getBand('B8')
        if (self.Index_Type == self.typeNDWI):
            print"Entre NDWI..."
            type=self.typeNDWI
            red_band = product.getBand('B11')
            nir_band = product.getBand('B8')
        if (self.Index_Type == self.typeNBAI):
            print"Entre NBAI..."
            type=self.typeNBAI
            do_band = product.getBand('B12')
            nir_band = product.getBand('B8')
            red_band = product.getBand('B2')
            do_row = numpy.zeros(width, dtype=numpy.float32)

        # output product (ndvi) & new band
        # output_product = Product('NDVI', 'NDVI', width, height)
        output_product = Product(self.Index_Type, self.Index_Type, width, height)
        ProductUtils.copyGeoCoding(product, output_product)
        output_band = output_product.addBand(type, ProductData.TYPE_FLOAT32)

        # output writer
        # Tam = len(image)
        fileOut = file[:-4] + '_' + self.Index_Type + '.dim'
        output_product_writer = ProductIO.getProductWriter('BEAM-DIMAP')
        output_product.setProductWriter(output_product_writer)
        # output_product.writeHeader(product_name + '.ndvi.dim')
        output_product.writeHeader(fileOut)

        # compute & save ndvi line by line
        red_row = numpy.zeros(width, dtype=numpy.float32)
        nir_row = numpy.zeros(width, dtype=numpy.float32)

        if (self.Index_Type == self.typeNDVI) or (self.Index_Type == self.typeNDWI):
            print"Entre NDVI o NDWI FOR..."
            for y in xrange(height):
                red_row = red_band.readPixels(0, y, width, 1, red_row)
                nir_row = nir_band.readPixels(0, y, width, 1, nir_row)
                ndvwi = (nir_row - red_row) / (nir_row + red_row)
                output_band.writePixels(0, y, width, 1, ndvwi)

        if (self.Index_Type == self.typeNBAI):
            print"Entre NBAI FOR..."
            for y in xrange(height):
                red_row = red_band.readPixels(0, y, width, 1, red_row)
                nir_row = nir_band.readPixels(0, y, width, 1, nir_row)
                do_row = do_band.readPixels(0, y, width, 1, do_row)
                nbai = (do_row - nir_row / red_row) / (do_row + nir_row / red_row)
                output_band.writePixels(0, y, width, 1, nbai)

        output_product.closeIO()

#Applying Index Flag=3 Search .dim files
#Find Sentinel Files
Files = tools("all") #IW_SLC,IW_GRDH,MSIL1C
dir="C:\Users\Garantias723\Documents\Poncho\Image_Sentinel"
platform='Sentinel-2'
list_files=Files.findFilesSentinel(dir,platform,3)
print 'There is/are %d ' % len(list_files) + platform + ' file(s)'
#Read Sentinel Files
Read=readProduct(dir,platform)
#Applying Resampling
Ind="NBAI"
Indeex=Index("60",Ind)
for image in list_files:
    file = dir + "\\" + image
    print"Applying Index "+Ind+"... ", image
    product=Read.ReadFilesSentinel(file,2)#The flag 2 ReadFiles .dim
    Indeex.Index(product,file)

#NDVI  - Normalized Difference Vegetation Index,
#NDWI - Normalized Difference Water Index,
#NBAI - Normalized Built-up Area Index