# -*- coding: utf-8 -*-
# @package Resample Sentinel Files
"""
Example:

        $ python -m doctest -v Resampling.py
"""

import os,sys
#sys.path.append(os.path.join(os.path.expandvars("%userprofile%"),".snap\snap-python"))
from os.path import expanduser
home = expanduser("~")
a=os.path.join(os.path.expandvars(home),".snap/snap-python/")
print"SNAPPY..",a
sys.path.append(a)
import snappy
from snappy import HashMap,jpy,Product,ProductData,ProductIO,ProductUtils
from tools import (tools)
from readProduct import (readProduct)

class Resampling(object):
    """ Class for Sentinel satellites configuration
    Test Case
    >>> Files = tools('MSIL1C')
    >>> dir="make/"
    >>> platform='Sentinel-2'
    >>> list_files=Files.findFilesSentinel(dir,platform,2)
    >>> print 'There is/are %d ' % len(list_files) + platform + ' file(s)'
    >>> Read=readProduct(dir,platform)
    >>> Resam = Resampling("60")
    >>> for image in list_files:
    >>> file = dir + "/" + image
    >>> print"Applying Resampling... ", image
    >>> product=Read.ReadFilesSentinel(file,1)
    >>> Resam.Resample(product, file)

     """
    def __init__(self,ResolSize):
        """The constructor Initialize Sentinel Data.

        Args:
            self: The object pointer.
            ResolSize (str): destination directory.

        Returns:
            pointer: The object pointer.
        """
        self.resolution=ResolSize
        self.Resampling = "Resample"
        self.method="NEAREST_NEIGHBOUR"
        self.HashMap = jpy.get_type('java.util.HashMap')

    def Resample(self,product,file):
        """Resample Files Sentinel

        Args:
            self (pointer): The object pointer.
            product (bin): Metadata Sentinel.
            file (str): local path to image.

        """
        params = self.HashMap()
        params.put('targetResolution', self.resolution)  # 10,20 or 60m
        params.put('demResamplingMethod', self.method)
        result = snappy.GPF.createProduct('Resample', params, product)
        outputRes = file[:-5] + "_" + self.Resampling + "_" + self.resolution + ".dim"
        ProductIO.writeProduct(result, outputRes, "BEAM-DIMAP")