# -*- coding: utf-8 -*-
# @package readProduct Sentinel Files
"""
Example:

        $ python -m doctest -v readProduct.py
"""



import os,sys
from os.path import expanduser
home = expanduser("~")
a=os.path.join(os.path.expandvars(home),".snap/snap-python/")
sys.path.append(a)
from snappy import Product,ProductData,ProductIO,ProductUtils
from tools import (tools)

class readProduct(object):
    """ Class for Sentinel satellites configuration
    Test Case
    >>> Files = tools('MSIL1C')
    >>> dir="make/"
    >>> platform='Sentinel-2'
    >>> list_files=Files.findFilesSentinel(dir,platform,2)
    >>> print 'There is/are %d ' % len(list_files) + platform + ' file(s)'
    >>> Read=readProduct(dir,platform)
    >>> for image in list_files:
    >>> file = dir + "/" + image
    >>> print"Reading image... ", image
    >>> product=Read.ReadFilesSentinel(file,1)
    >>> band_names = product.getBandNames()
    >>> print("Bands:   %s" % (list(band_names)))

     """

    def __init__(self,folder,platform):
        """The constructor Initialize Sentinel Data.

        Args:
            self: The object pointer.
            folder (str): destination directory.
            platform (str): Sentinel-1 or Sentinel-2.

        Returns:
            pointer: The object pointer.
        """
        self.dir=folder
        self.platform=platform

    def ReadFilesSentinel(self,file,flag):
        """Read Files Sentinel

        Args:
            self (pointer): The object pointer.
            file (str): Sentinel Product list found.
            flag (int): File Type to read .xml or .dim.

        Returns:
            sentinel (bin): Metadata Sentinel.

        """

        # Extract information about the Sentinel product:
        if(self.platform=="Sentinel-2"):
            if (flag==1):
                sentinel = ProductIO.readProduct(file + "/MTD_MSIL1C.xml")
            if (flag==2):
                sentinel = ProductIO.readProduct(file)
        if (self.platform=="Sentinel-1"):
            sentinel = ProductIO.readProduct(file + "/manifest.safe")
        return sentinel
